@@ -61,21 +61,21 @@ class PatchRepositoryIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
 # overridde vcreview summary tables to include patch's ticket and ticket's
 # version
 vcreview_startup.AllActivePatches.rql = (
-    'Any P,PO,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
+    'Any P,PO,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
     'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS, '
     'TR? wf_info_for P, P patch_repository R, R title RT, '
-    'PS name IN ("in-progress", "pending-review", "deleted"), '
+    'PS name %s, '
     'P patch_ticket T?, T done_in V?')
 vcreview_startup.UserWorkList.rql = (
-    'Any P,PO,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
+    'Any P,PO,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
     'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
     'TR? wf_info_for P, P patch_repository R, R title RT, U eid %(u)s, '
     'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
-    'OR EXISTS(PS name IN ("reviewed", "deleted") AND EXISTS(R repository_committer U) '
-    'OR EXISTS(U in_group G, G name "commiters")), '
+    'OR EXISTS(PS name IN ("reviewed", "deleted") AND (EXISTS(R repository_committer U) '
+    'OR EXISTS(U in_group G, G name "committers"))), '
     'P patch_ticket T?, T done_in V?')
 vcreview_primary.RepositoryPatchesTable.rql = (
-    'Any P,PO,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
+    'Any P,PO,P,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
     'P originator PO, P branch PB, P in_state PS, TR? wf_info_for P, '
     'P patch_repository R, R eid %(x)s, '
     'P patch_ticket T?, T done_in V?')
